@@ -28,7 +28,6 @@
 #include "libgui/MouseMark.h"
 #include "libgui/ViewItem.h"
 
-class QWidget;
 
 namespace Kwave
 {
@@ -50,13 +49,13 @@ namespace Kwave
                             sample_index_t pos);
 
         /** Destructor */
-        virtual ~SelectionBorderItem() Q_DECL_OVERRIDE;
+        ~SelectionBorderItem() override;
 
         /**
          * Returns flags describing the possible interactions with this object
          * @see Kwave::ViewItem::Flags
          */
-        virtual Kwave::ViewItem::Flags flags() const Q_DECL_OVERRIDE;
+        Kwave::ViewItem::Flags flags() const override;
 
         /**
          * Can be overwritten to return a tooltip. The default implementation
@@ -65,19 +64,19 @@ namespace Kwave
          * @param ofs sample index the tooltip should refer to (unused)
          * @return an already localized tooltip
          */
-        virtual QString toolTip(sample_index_t &ofs) Q_DECL_OVERRIDE;
+        QString toolTip(sample_index_t &ofs) override;
 
         /**
          * Returns a mouse cursor used when moving the item
          */
-        virtual QCursor mouseCursor() const Q_DECL_OVERRIDE;
+        QCursor mouseCursor() const override;
 
         /**
          * handles updates when being moved with the mouse
          * @param mouse_pos position of the mouse, in pixel coordinates
          *                  relative to the parent widget
          */
-        virtual void moveTo(const QPoint &mouse_pos) Q_DECL_OVERRIDE;
+        void moveTo(const QPoint &mouse_pos) override;
 
     private:
 
