@@ -19,6 +19,7 @@
 #define SIGNAL_WIDGET_H
 
 #include "config.h"
+#include "libkwavegui_export.h"
 
 #include <QtGlobal>
 #include <QGridLayout>
@@ -41,30 +42,16 @@
 
 #include "libgui/SignalView.h"
 
-class QBitmap;
 class QContextMenuEvent;
-class QDragEnterEvent;
-class QDragMoveEvent;
-class QDropEvent;
-class QDragLeaveEvent;
-class QEvent;
-class QMouseEvent;
-class QMoveEvent;
-class QPaintEvent;
 class QPoint;
 class QVBoxLayout;
 class QWheelEvent;
 
-class QUrl;
 
-class LabelType;
-class TimeOperation;
-class TrackPixmap;
 
 namespace Kwave
 {
 
-    class FileContext;
     class SignalManager;
     class Track;
 
@@ -72,7 +59,7 @@ namespace Kwave
      * The SignalWidget class is responsible for displaying and managing the
      * views that belong to a signal.
      */
-    class Q_DECL_EXPORT SignalWidget: public QWidget,
+    class LIBKWAVEGUI_EXPORT SignalWidget: public QWidget,
                                       public Kwave::ViewManager
     {
         Q_OBJECT
@@ -91,7 +78,7 @@ namespace Kwave
                      QVBoxLayout *upper_dock, QVBoxLayout *lower_dock);
 
         /** Destructor */
-        virtual ~SignalWidget() Q_DECL_OVERRIDE;
+        ~SignalWidget() override;
 
         /**
          * sets new zoom factor and offset
@@ -120,7 +107,7 @@ namespace Kwave
          * @param controls a widget with controls, optionally, can be null
          */
         virtual void insertView(Kwave::SignalView *view, QWidget *controls)
-            Q_DECL_OVERRIDE;
+            override;
 
     signals:
 
@@ -141,7 +128,7 @@ namespace Kwave
     protected slots:
 
         /** Handler for context menus */
-        virtual void contextMenuEvent(QContextMenuEvent *e) Q_DECL_OVERRIDE;
+        void contextMenuEvent(QContextMenuEvent *e) override;
 
     private slots:
 
@@ -233,7 +220,7 @@ namespace Kwave
     protected:
 
         /** slot for mouse wheel events, used for vertical zoom */
-        virtual void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
+        void wheelEvent(QWheelEvent *event) override;
 
     private:
 
