@@ -21,6 +21,7 @@
 
 #include <QApplication>
 #include <QDateTime>
+#include <QMetaType>
 #include <QMutexLocker>
 #include <QUuid>
 
@@ -190,6 +191,15 @@ sample_index_t Kwave::MetaData::lastSample() const
     return SAMPLE_INDEX_MAX;
 }
 
+//***************************************************************************
+static inline QString shortened(const QString &str)
+{
+    if (str.length() < 1024)
+        return _("'") + str + _("'");
+    else
+        return _("'") + str.left(1024) + _("'...");
+}
+
 //***************************************************************************
 void Kwave::MetaData::dump() const
 {
@@ -201,18 +211,24 @@ void Kwave::MetaData::dump() const
 
     qDebug("    scope =%s", DBG(scope_list));
     const QStringList props = keys();
-    foreach (const QString &p, props) {
-        QVariant prop = property(p);
-        const QList<QVariant> v_vals = prop.toList();
-        QString value;
-        if (!v_vals.isEmpty()) {
-            foreach (QVariant v, v_vals)
-                value += _("{") + v.toString() + _("'} ");
-        } else {
-            value += _("'") + prop.toString() + _("'");
+    foreach (const QString &name, props) {
+        QVariant    val  = property(name);
+        QStringList list = val.toStringList();
+        if (list.size() > 1)
+        {
+            int index = 0;
+            foreach (const QString &v, list)
+            {
+                if (index > 32) {
+                    qDebug("    ..."); // emergency break
+                    break;
+                }
+                qDebug("   '%s[%2d]' = %s", DBG(name), index++,
+                       DBG(shortened(v)));
+            }
         }
-
-        qDebug("    '%s' = %s", DBG(p), DBG(value));
+        else
+            qDebug("   '%s' = %s", DBG(name), DBG(shortened(val.toString())));
     }
 }
 
