@@ -19,6 +19,7 @@
 #define SAMPLE_ENCODER_LINEAR_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 
@@ -28,7 +29,7 @@
 
 namespace Kwave
 {
-    class Q_DECL_EXPORT SampleEncoderLinear: public Kwave::SampleEncoder
+    class LIBKWAVE_EXPORT SampleEncoderLinear: public Kwave::SampleEncoder
     {
     public:
 
@@ -43,7 +44,7 @@ namespace Kwave
                             Kwave::byte_order_t endianness);
 
         /** Destructor */
-        virtual ~SampleEncoderLinear() Q_DECL_OVERRIDE;
+        ~SampleEncoderLinear() override;
 
         /**
          * Encodes a buffer with samples into a buffer with raw data.
@@ -53,10 +54,10 @@ namespace Kwave
          */
         virtual void encode(const Kwave::SampleArray &samples,
                             unsigned int count,
-                            QByteArray &raw_data) Q_DECL_OVERRIDE;
+                            QByteArray &raw_data) override;
 
         /** Returns the number of bytes per sample in raw (encoded) form */
-        virtual unsigned int rawBytesPerSample() Q_DECL_OVERRIDE;
+        unsigned int rawBytesPerSample() override;
 
     private:
 
