@@ -36,6 +36,14 @@ Kwave::Stripe::Stripe(const Stripe &other)
 {
 }
 
+//***************************************************************************
+Kwave::Stripe::Stripe(Stripe &&other)
+    :m_lock(), m_start(other.m_start), m_data(other.m_data)
+{
+    other.m_start = 0;
+    other.m_data.resize(0);
+}
+
 //***************************************************************************
 Kwave::Stripe::Stripe(sample_index_t start)
     :m_lock(), m_start(start), m_data()
@@ -72,6 +80,18 @@ Kwave::Stripe::~Stripe()
     QMutexLocker lock(&m_lock);
 }
 
+//***************************************************************************
+Kwave::Stripe & Kwave::Stripe::operator = (Kwave::Stripe &&other) noexcept
+{
+    if (this != &other) {
+        m_start = other.m_start;
+        m_data  = other.m_data;
+        other.m_start = 0;
+        other.m_data.resize(0);
+    }
+    return *this;
+}
+
 //***************************************************************************
 sample_index_t Kwave::Stripe::start() const
 {
