@@ -27,7 +27,7 @@ bool Kwave::StreamObject::m_interactive = false;
 
 //***************************************************************************
 Kwave::StreamObject::StreamObject(QObject *parent)
-    :QObject(Q_NULLPTR /*parent*/),
+    :QObject(nullptr /*parent*/),
      m_lock_set_attribute(),
      m_canceled(false)
 {
@@ -86,3 +86,5 @@ void Kwave::StreamObject::cancel()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_StreamObject.cpp"
