@@ -19,6 +19,7 @@
 #define UNDO_HANDLER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 
@@ -27,7 +28,7 @@ namespace Kwave
 
     class UndoTransaction;
 
-    class Q_DECL_EXPORT UndoHandler
+    class LIBKWAVE_EXPORT UndoHandler
     {
     public:
 
