@@ -105,7 +105,7 @@ bool Kwave::UndoModifyMetaDataAction::store(Kwave::SignalManager &)
 Kwave::UndoAction *Kwave::UndoModifyMetaDataAction::undo(
     Kwave::SignalManager &manager, bool with_redo)
 {
-    if (m_saved_data.isEmpty()) return Q_NULLPTR;
+    if (m_saved_data.isEmpty()) return nullptr;
 
     // store data for redo
     if (with_redo) {
@@ -134,7 +134,7 @@ Kwave::UndoAction *Kwave::UndoModifyMetaDataAction::undo(
     } else {
         // restore the saved meta data
         manager.mergeMetaData(m_saved_data);
-        return Q_NULLPTR;
+        return nullptr;
     }
 }
 
@@ -149,7 +149,7 @@ void Kwave::UndoModifyMetaDataAction::dump(const QString &indent)
         foreach (const QString &key, m.keys()) {
             QVariant v = m[key];
             QString value;
-            if (v.type() == QVariant::List) {
+            if (v.typeId() == QMetaType::QVariantList) {
                 foreach (const QVariant &v1, v.toList())
                     value += _("'") + v1.toString() + _("' ");
             } else {
