@@ -43,13 +43,13 @@ namespace Kwave
         BandPass();
 
         /** Destructor */
-        virtual ~BandPass() Q_DECL_OVERRIDE;
+        ~BandPass() override;
 
         /** does the calculation */
-        virtual void goOn() Q_DECL_OVERRIDE;
+        void goOn() override;
 
         /** @see TransmissionFunction::at() */
-        virtual double at(double f) Q_DECL_OVERRIDE;
+        double at(double f) override;
 
     signals:
 
