@@ -53,7 +53,7 @@ QStringList *Kwave::FileInfoPlugin::setup(QStringList &)
     QPointer<Kwave::FileInfoDialog> dialog =
         new(std::nothrow) Kwave::FileInfoDialog(parentWidget(), oldInfo);
     Q_ASSERT(dialog);
-    if (!dialog) return Q_NULLPTR;
+    if (!dialog) return nullptr;
 
     QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
@@ -62,11 +62,11 @@ QStringList *Kwave::FileInfoPlugin::setup(QStringList &)
         apply(dialog->info());
     } else {
         // user pressed "Cancel"
-        if (list) delete list;
-        list = Q_NULLPTR;
+        delete list;
+        list = nullptr;
     }
 
-    if (dialog) delete dialog;
+    delete dialog;
     return list;
 }
 
@@ -123,3 +123,5 @@ void Kwave::FileInfoPlugin::apply(Kwave::FileInfo &new_info)
 #include "FileInfoPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_FileInfoPlugin.cpp"
