@@ -28,8 +28,6 @@
 
 #include "ui_LowPassDlg.h"
 
-class QStringList;
-
 namespace Kwave
 {
 
@@ -52,16 +50,16 @@ namespace Kwave
         LowPassDialog(QWidget *parent, double sample_rate);
 
         /** Destructor */
-        virtual ~LowPassDialog() Q_DECL_OVERRIDE;
+        ~LowPassDialog() override;
 
         /** Returns the parameters as string list */
-        virtual QStringList params() Q_DECL_OVERRIDE;
+        QStringList params() override;
 
         /** Sets the from a list of parameters */
-        virtual void setParams(QStringList &params) Q_DECL_OVERRIDE;
+        void setParams(QStringList &params) override;
 
         /** retruns a pointer to this as a QDialog */
-        virtual QDialog *dialog() Q_DECL_OVERRIDE { return this; }
+        QDialog *dialog() override { return this; }
 
     signals:
 
