@@ -26,8 +26,6 @@
 #include "libkwave/WindowFunction.h"
 #include "ui_SonagramDlg.h"
 
-class QStringList;
-
 namespace Kwave
 {
 
@@ -42,7 +40,7 @@ namespace Kwave
         explicit SonagramDialog(Kwave::Plugin &p);
 
         /** Destructor */
-        virtual ~SonagramDialog();
+        ~SonagramDialog() override;
 
         /**
          * Fills the current parameters into a parameter list.
