@@ -83,17 +83,17 @@ static const char *background[] = {
 //****************************************************************************
 Kwave::SonagramWindow::SonagramWindow(QWidget *parent, const QString &name)
     :KMainWindow(parent),
-     m_status_time(Q_NULLPTR),
-     m_status_freq(Q_NULLPTR),
-     m_status_ampl(Q_NULLPTR),
+     m_status_time(nullptr),
+     m_status_freq(nullptr),
+     m_status_ampl(nullptr),
      m_image(),
      m_color_mode(0),
-     m_view(Q_NULLPTR),
-     m_overview(Q_NULLPTR),
+     m_view(nullptr),
+     m_overview(nullptr),
      m_points(0),
      m_rate(0),
-     m_xscale(Q_NULLPTR),
-     m_yscale(Q_NULLPTR),
+     m_xscale(nullptr),
+     m_yscale(nullptr),
      m_refresh_timer()
 {
 
@@ -131,8 +131,8 @@ Kwave::SonagramWindow::SonagramWindow(QWidget *parent, const QString &name)
     file->addAction(
         QIcon::fromTheme(_("dialog-close")),
         i18n("&Close"),
-        this, SLOT(close()),
-        QKeySequence::Close
+        QKeySequence::Close,
+        this, SLOT(close())
     );
 
 //    spectral->addAction(i18n("&Retransform to Signal"), this,
@@ -320,7 +320,7 @@ void Kwave::SonagramWindow::insertSlice(const unsigned int slice_nr,
     if (slice_nr >= image_width) return;
 
     unsigned int y;
-    unsigned int size = slice.size();
+    unsigned int size = static_cast<unsigned int>(slice.size());
     for (y = 0; y < size; y++) {
         quint8 p;
 
@@ -581,3 +581,5 @@ void Kwave::SonagramWindow::setRate(double rate)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_SonagramWindow.cpp"
