@@ -70,7 +70,7 @@ QStringList *Kwave::StringEnterPlugin::setup(QStringList &previous_params)
     QPointer<Kwave::StringEnterDialog> dialog =
         new(std::nothrow) Kwave::StringEnterDialog(parentWidget(), preset);
     Q_ASSERT(dialog);
-    if (!dialog) return Q_NULLPTR;
+    if (!dialog) return nullptr;
 
     QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
@@ -80,11 +80,11 @@ QStringList *Kwave::StringEnterPlugin::setup(QStringList &previous_params)
         emitCommand(command);
     } else {
         // user pressed "Cancel"
-        if (list) delete list;
-        list = Q_NULLPTR;
+        delete list;
+        list = nullptr;
     }
 
-    if (dialog) delete dialog;
+    delete dialog;
     return list;
 }
 
@@ -92,3 +92,5 @@ QStringList *Kwave::StringEnterPlugin::setup(QStringList &previous_params)
 #include "StringEnterPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_StringEnterPlugin.cpp"
